========
Tutorial
========

Please follow the Jupyter notebook tutorials, rendered by Github: https://github.com/alexlib/openpiv-python/blob/master/openpiv/examples/notebooks/tutorial1.ipynb or by NBViewer:

https://nbviewer.jupyter.org/github/alexlib/openpiv-python/blob/master/openpiv/examples/notebooks/tutorial1.ipynb

There are few tutorials available for the pure Python and Cython, windows deformation multi-pass algorithm and dynamic masking of moving objects

https://nbviewer.jupyter.org/github/alexlib/openpiv-python/tree/master/openpiv/examples/notebooks/





    

